# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-04-08 12:20
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_customers', '0005_productpagevisit'),
    ]

    operations = [
        migrations.CreateModel(
            name='WishList',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('title', models.CharField(max_length=150, verbose_name='Title')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
                ('added', models.DateTimeField(auto_now_add=True, verbose_name='Added')),
                ('changed', models.DateTimeField(auto_now=True, verbose_name='Changed')),
                ('customer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='pcart_customers.Customer', verbose_name='Customer')),
            ],
            options={
                'verbose_name_plural': 'Wish lists',
                'verbose_name': 'Wish list',
                'ordering': ['title'],
            },
        ),
        migrations.AlterModelOptions(
            name='productpagevisit',
            options={'ordering': ['-changed'], 'verbose_name': 'Product page visit', 'verbose_name_plural': 'Product pages visits'},
        ),
        migrations.AlterUniqueTogether(
            name='wishlist',
            unique_together=set([('title', 'customer')]),
        ),
    ]
