from cms.app_base import CMSApp
from cms.apphook_pool import apphook_pool
from django.utils.translation import ugettext_lazy as _


class CustomersApphook(CMSApp):
    app_name = "pcart_customers"
    name = _("Customer")

    def get_urls(self, page=None, language=None, **kwargs):
        return ["pcart_customers.urls"]

apphook_pool.register(CustomersApphook)