# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-04-12 09:52
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_customers', '0008_comparisonproduct'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='comparisonproduct',
            name='customer',
        ),
        migrations.RemoveField(
            model_name='comparisonproduct',
            name='product',
        ),
        migrations.RemoveField(
            model_name='comparisonproduct',
            name='variant',
        ),
        migrations.RemoveField(
            model_name='productpagevisit',
            name='customer',
        ),
        migrations.RemoveField(
            model_name='productpagevisit',
            name='product',
        ),
        migrations.RemoveField(
            model_name='productpagevisit',
            name='variant',
        ),
        migrations.AlterUniqueTogether(
            name='wishlist',
            unique_together=set([]),
        ),
        migrations.RemoveField(
            model_name='wishlist',
            name='customer',
        ),
        migrations.RemoveField(
            model_name='wishlistedproduct',
            name='product',
        ),
        migrations.RemoveField(
            model_name='wishlistedproduct',
            name='variant',
        ),
        migrations.RemoveField(
            model_name='wishlistedproduct',
            name='wish_list',
        ),
        migrations.DeleteModel(
            name='ComparisonProduct',
        ),
        migrations.DeleteModel(
            name='ProductPageVisit',
        ),
        migrations.DeleteModel(
            name='WishList',
        ),
        migrations.DeleteModel(
            name='WishListedProduct',
        ),
    ]
