# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-01 18:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_customers', '0003_passwordresetlink'),
    ]

    operations = [
        migrations.AlterField(
            model_name='passwordresetlink',
            name='slug',
            field=models.CharField(blank=True, max_length=120, unique=True, verbose_name='Slug'),
        ),
    ]
