# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-04-09 09:03
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_catalog', '0013_collection_exclude_properties_filters'),
        ('pcart_customers', '0007_wishlistedproduct'),
    ]

    operations = [
        migrations.CreateModel(
            name='ComparisonProduct',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('added', models.DateTimeField(auto_now_add=True, verbose_name='Added')),
                ('changed', models.DateTimeField(auto_now=True, verbose_name='Changed')),
                ('customer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='comparison_products', to='pcart_customers.Customer', verbose_name='Customer')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='comparison', to='pcart_catalog.Product', verbose_name='Product')),
                ('variant', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='comparison', to='pcart_catalog.ProductVariant', verbose_name='Variant')),
            ],
            options={
                'verbose_name': 'Comparison product',
                'ordering': ['-added'],
                'verbose_name_plural': 'Comparison products',
            },
        ),
    ]
