# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-01 17:56
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('pcart_customers', '0002_auto_20170223_2055'),
    ]

    operations = [
        migrations.CreateModel(
            name='PasswordResetLink',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('slug', models.CharField(max_length=120, unique=True, verbose_name='Slug')),
                ('active', models.BooleanField(default=True, verbose_name='Active')),
                ('added', models.DateTimeField(auto_now_add=True, verbose_name='Added')),
                ('expiration_date', models.DateTimeField(verbose_name='Expiration date')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='password_reset_link', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Password reset link',
                'verbose_name_plural': 'Password reset links',
            },
        ),
    ]
